==> hestia_earth_models-0.0.7-py3-none-any.whl: hestia_earth/models/globalCropWaterModel2008/rootingDepth.py <==
from hestia_earth.utils.api import download_hestia
from hestia_earth.utils.model import find_term_match
from hestia_earth.utils.lookup import get_table_value, download_lookup
from hestia_earth.utils.tools import non_empty_list, safe_parse_float

from hestia_earth.models.log import logger
from hestia_earth.models.data.properties import _load_property
from hestia_earth.models.utils.property import _new_property

TERM_ID = 'rootingDepth'


def _property(value: float, term: dict):
    logger.info('term=%s, value=%s', TERM_ID, value)
    prop = _new_property(term)
    prop['value'] = value
    return prop


def _get_input_value_from_term(inputs: list, term_id: str):
    val = find_term_match(inputs, term_id, None)
    return val.get('value', [0])[0] if val is not None else 0


def _get_value(cycle: dict, term: dict, irrigation_names: list):
    lookup = download_lookup('crop.csv', True)
    term_id = term.get('@id', '')

    in_lookup = term_id in list(lookup.termid)
    logger.debug('Found lookup data for Term: %s? %s', term_id, in_lookup)

    if in_lookup:
        # add an if statement to catch the irrigation level
        if cycle.get('dataCompleteness').get('water', False):
            value = sum([_get_input_value_from_term(cycle.get('inputs', []), term_id) for term_id in irrigation_names])

            # Assumes that if water data is complete and there are no data on irrigation then there was no irrigation.
            column = 'rooting_depth_irrigated_m' if value > 0 else 'rooting_depth_rainfed_m'
        else:
            column = 'rooting_depth_average_m'

        value = safe_parse_float(get_table_value(lookup, 'termid', term_id, column), 0)
        return value if value > 0 else None
    return None


def _should_run(product: dict):
    should_run = find_term_match(product.get('properties', []), TERM_ID, None) is None
    logger.info('term=%s, should_run=%s', TERM_ID, should_run)
    return should_run


def _run_cycle(cycle: dict, products: list):
    term = download_hestia(TERM_ID)
    irrigation_names = _load_property('irrigations.txt').split('\n')

    def run_product(product):
        value = _get_value(cycle, product.get('term'), irrigation_names)
        property = _property(value, term) if value is not None and term is not None else None
        product['properties'] = product.get('properties', []) + ([property] if property else [])
        return product

    return non_empty_list(map(run_product, products))


def run(cycle: dict):
    products = list(filter(_should_run, cycle.get('products', [])))
    return _run_cycle(cycle, products) if len(products) > 0 else []

==> hestia_earth_models-0.0.8-py3-none-any.whl: hestia_earth/models/globalCropWaterModel2008/rootingDepth.py <==
from hestia_earth.utils.api import download_hestia
from hestia_earth.utils.model import find_term_match
from hestia_earth.utils.lookup import get_table_value, download_lookup
from hestia_earth.utils.tools import non_empty_list, safe_parse_float

from hestia_earth.models.log import logger
from hestia_earth.models.data.properties import _load_property
from hestia_earth.models.utils.property import _new_property

TERM_ID = 'rootingDepth'


def _property(value: float, term: dict):
    logger.info('term=%s, value=%s', TERM_ID, value)
    prop = _new_property(term)
    prop['value'] = value
    return prop


def _get_input_value_from_term(inputs: list, term_id: str):
    val = find_term_match(inputs, term_id, None)
    return val.get('value', [0])[0] if val is not None else 0


def _get_value(cycle: dict, term: dict, irrigation_names: list):
    lookup = download_lookup('crop.csv', True)
    term_id = term.get('@id', '')

    in_lookup = term_id in list(lookup.termid)
    logger.debug('Found lookup data for Term: %s? %s', term_id, in_lookup)

    if in_lookup:
        # add an if statement to catch the irrigation level
        if cycle.get('dataCompleteness').get('water', False):
            value = sum([_get_input_value_from_term(cycle.get('inputs', []), term_id) for term_id in irrigation_names])

            # Assumes that if water data is complete and there are no data on irrigation then there was no irrigation.
            column = 'rooting_depth_irrigated_m' if value > 0 else 'rooting_depth_rainfed_m'
        else:
            column = 'rooting_depth_average_m'

        value = safe_parse_float(get_table_value(lookup, 'termid', term_id, column), 0)
        return value if value > 0 else None
    return None


def _should_run(product: dict):
    should_run = find_term_match(product.get('properties', []), TERM_ID, None) is None
    logger.info('term=%s, should_run=%s', TERM_ID, should_run)
    return should_run


def _run_cycle(cycle: dict, products: list):
    term = download_hestia(TERM_ID)
    irrigation_names = _load_property('irrigations.txt').split('\n')

    def run_product(product):
        value = _get_value(cycle, product.get('term'), irrigation_names)
        prop = _property(value, term) if value is not None and term is not None else None
        return {**product, 'properties': product.get('properties', []) + [prop]} if prop else product

    return non_empty_list(map(run_product, products))


def run(cycle: dict):
    products = list(filter(_should_run, cycle.get('products', [])))
    return _run_cycle(cycle, products) if len(products) > 0 else []
